@@ -47,6 +47,8 @@ class QWidgetAction;
  * */
 class FractionRingWidget : public KXmlGuiWindow
 {
+    Q_OBJECT
+
 public:
     /** constructor */
     FractionRingWidget();
@@ -106,6 +108,7 @@ private:
 
     void setupActions();
 
+private Q_SLOTS:
     void slotLeftSpinBoxValueChanged(int value);
     void slotRightSpinBoxValueChanged(int value);
     void NewTask();
